summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorManman Ren <manman.ren@gmail.com>2013-12-03 00:12:14 +0000
committerManman Ren <manman.ren@gmail.com>2013-12-03 00:12:14 +0000
commit44de223927a6d32f599574b4d10093ce041c1acd (patch)
tree02cdda27bcc1bab5273ce49f462327a5207edaa6 /lib
parentff40d5e6d4de593f325cac261cf58109cca8239f (diff)
downloadllvm-44de223927a6d32f599574b4d10093ce041c1acd.tar.gz
llvm-44de223927a6d32f599574b4d10093ce041c1acd.tar.bz2
llvm-44de223927a6d32f599574b4d10093ce041c1acd.tar.xz
Debug Info: rename getDebugInfoVersionFromModule to getDebugMetadataVersionFromModule.
Suggested by Eric. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@196172 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib')
-rw-r--r--lib/IR/AutoUpgrade.cpp2
-rw-r--r--lib/IR/DebugInfo.cpp4
2 files changed, 3 insertions, 3 deletions
diff --git a/lib/IR/AutoUpgrade.cpp b/lib/IR/AutoUpgrade.cpp
index 32cfe278c7..d12bf7b9e3 100644
--- a/lib/IR/AutoUpgrade.cpp
+++ b/lib/IR/AutoUpgrade.cpp
@@ -494,7 +494,7 @@ Value *llvm::UpgradeBitCastExpr(unsigned Opc, Constant *C, Type *DestTy) {
/// Check the debug info version number, if it is out-dated, drop the debug
/// info. Return true if module is modified.
bool llvm::UpgradeDebugInfo(Module &M) {
- if (getDebugInfoVersionFromModule(M) == DEBUG_METADATA_VERSION)
+ if (getDebugMetadataVersionFromModule(M) == DEBUG_METADATA_VERSION)
return false;
return StripDebugInfo(M);
diff --git a/lib/IR/DebugInfo.cpp b/lib/IR/DebugInfo.cpp
index 68015b759a..75a70965a3 100644
--- a/lib/IR/DebugInfo.cpp
+++ b/lib/IR/DebugInfo.cpp
@@ -1478,8 +1478,8 @@ bool llvm::StripDebugInfo(Module &M) {
return Changed;
}
-/// Return Debug Info Version by checking module flags.
-unsigned llvm::getDebugInfoVersionFromModule(const Module &M) {
+/// Return Debug Info Metadata Version by checking module flags.
+unsigned llvm::getDebugMetadataVersionFromModule(const Module &M) {
Value *Val = M.getModuleFlag("Debug Info Version");
if (!Val)
return 0;